@@ -10,13 +10,10 @@ urllib3.disable_warnings(urllib3.exceptions.InsecureRequestWarning)
 def enter_and_leave_function(func):
     @functools.wraps(func)
     def wrapper(*args, **kwargs):
-        log.info(f"begin to run function {func.__name__}")
+        log.info(f"begin to run function {func.__name__},args is '{args}',kwargs is '{kwargs}'")
         try:
             result = func(*args, **kwargs)
-            if not result:
-                log.warn(f"finish run function {func.__name__},args is {args},kwargs is {kwargs}, but result is None")
-            else:
-                log.info(f"finish run function {func.__name__}")
+            log.info(f"finish run function {func.__name__}, return value is '{result}")
             return result
         except Exception as e:
             log.error(f"failed to run functon {func.__name__} error message is : {e}")
@@ -49,8 +46,8 @@ class CloudPods:
     def sku(self):
         return self.__sku
 
-    @enter_and_leave_function
     def __get_session(self):
+        log.info(f"begin to get session ...")
         session = requests.Session()
         headers = {
             "User-Agent": "yunioncloud-go/201708"
@@ -98,6 +95,7 @@ class CloudPods:
             log.info(f"Get /auth/tokens success. token is {token}")
             headers['X-Auth-Token'] = token
             session.headers.update(headers)
+            log.info(f"Get session success: OK.")
             return session
         except Exception as e:
             log.error(f"Failed to get /auth/tokens: Error. err msg is {str(e)}", exc_info=True)
